==> haskell-yesod-static-1.6.0.1-233-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.6.0.1
id: yesod-static-1.6.0.1-4aSBHdt6i6hGTCgZ8qeG6Q
key: yesod-static-1.6.0.1-4aSBHdt6i6hGTCgZ8qeG6Q
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
abi: 844b78495785ac0ce650ed85befb4e58
exposed: True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-static-1.6.0.1
hs-libraries: HSyesod-static-1.6.0.1-4aSBHdt6i6hGTCgZ8qeG6Q
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    conduit-1.3.1.1-7rushQ980336tJPFaKI7Kn containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-6pgPBMHIdu0Fbd6Y3tmeLl
    css-text-0.1.3.0-LlBHo1ngVsF1sRnX9Z0aY3
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsmin-0.2.0.4-JdaGi79JbWbIYBzLTeX5ol
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk process-1.6.5.0
    template-haskell-2.14.0.0 text-1.2.3.1 transformers-0.5.6.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-app-static-3.1.6.3-2sMsP1AOjUk8XQxJJ69GEi
    yesod-core-1.6.16.1-CnjctK5jU6WAJRiz7znykh
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.0.1-237-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.6.0.1
id: yesod-static-1.6.0.1-76AHMEcETnl5myExO34dh4
key: yesod-static-1.6.0.1-76AHMEcETnl5myExO34dh4
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
abi: 735af3adcc0074c8e2a120192fcc30c2
exposed: True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/yesod-static-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/yesod-static-1.6.0.1
hs-libraries: HSyesod-static-1.6.0.1-76AHMEcETnl5myExO34dh4
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    conduit-1.3.1.1-223VZeefHKZIaNcv3a4V93 containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-4ciAHUXJNfE27gVa6vyMwH
    css-text-0.1.3.0-LlBHo1ngVsF1sRnX9Z0aY3
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ directory-1.3.3.0
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsmin-0.2.0.4-JdaGi79JbWbIYBzLTeX5ol
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk process-1.6.5.0
    template-haskell-2.14.0.0 text-1.2.3.1 transformers-0.5.6.2
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    wai-3.2.2.1-LiO6tjlOPxLE7Ud9tulQOy
    wai-app-static-3.1.6.3-KYVzWhuV7ROFOTr1vOtjAr
    yesod-core-1.6.17-IfKo9B8PbmWFE6igxnJQOa
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
